@@ -7,26 +7,11 @@ use strict;
 
 package POSIX::1003::FS;
 use vars '$VERSION';
-$VERSION = '0.99_06';
+$VERSION = '0.99_07';
 
 use base 'POSIX::1003::Module';
 
-# Blocks resp from unistd.h, stdio.h, limits.h
-my @constants;
-my @access = qw/access/;
-my @stat   = qw/stat lstat mkfifo mknod mkdir lchown
-  S_ISDIR S_ISCHR S_ISBLK S_ISREG S_ISFIFO S_ISLNK S_ISSOCK S_ISWHT
-/;
-my @glob = qw/posix_glob/;  # fnmatch
-
-sub S_ISDIR($)  { ($_[0] & S_IFMT()) == S_IFDIR()}
-sub S_ISCHR($)  { ($_[0] & S_IFMT()) == S_IFCHR()}
-sub S_ISBLK($)  { ($_[0] & S_IFMT()) == S_IFBLK()}
-sub S_ISREG($)  { ($_[0] & S_IFMT()) == S_IFREG()}
-sub S_ISFIFO($) { ($_[0] & S_IFMT()) == S_IFIFO()}
-sub S_ISLNK($)  { ($_[0] & S_IFMT()) == S_IFLNK()}
-sub S_ISSOCK($) { ($_[0] & S_IFMT()) == S_IFSOCK()}
-sub S_ISWHT($)  { ($_[0] & S_IFMT()) == S_IFWHT()}  # FreeBSD
+my (@constants, @access, @stat, @glob);
 
 # POSIX.xs defines L_ctermid L_cuserid L_tmpname: useless!
 
@@ -40,33 +25,38 @@ my @functions = qw/
 our @IN_CORE     = qw(utime mkdir stat lstat rename);
 
 our %EXPORT_TAGS =
- ( constants => \@constants
- , functions => \@functions
- , access    => \@access
- , stat      => \@stat
- , glob      => \@glob
- , tables    => [ qw/%access %stat/ ]
- );
+  ( constants => \@constants
+  , functions => \@functions
+  , access    => \@access
+  , stat      => \@stat
+  , glob      => \@glob
+  , tables    => [ qw/%access %stat/ ]
+  );
 
 my ($fsys, %access, %stat, %glob);
 
-BEGIN {
-    $fsys = fsys_table;
+BEGIN
+  { $fsys = fsys_table;
     push @constants, keys %$fsys;
 
     # initialize the :access export tag
+    @access = qw/access/;
     push @access, grep /_OK$|MAX/, keys %$fsys;
     my %access_subset;
     @access_subset{@access} = @{$fsys}{@access};
     tie %access,  'POSIX::1003::ReadOnlyTable', \%access_subset;
 
     # initialize the :stat export tag
+    @stat = qw/stat lstat mkfifo mknod mkdir lchown
+        S_ISDIR S_ISCHR S_ISBLK S_ISREG S_ISFIFO S_ISLNK S_ISSOCK S_ISWHT
+        /;
     push @stat, grep /^S_I/, keys %$fsys;
     my %stat_subset;
     @stat_subset{@stat} = @{$fsys}{@stat};
     tie %stat, 'POSIX::1003::ReadOnlyTable', \%stat_subset;
 
     # initialize the :fsys export tag
+    @glob = qw/posix_glob fnmatch/;
     push @glob, grep /^(?:GLOB|FNM|WRDE)_/, keys %$fsys;
     my %glob_subset;
     @glob_subset{@glob} = @{$fsys}{@glob};
@@ -74,6 +64,16 @@ BEGIN {
 }
 
 
+sub S_ISDIR($)  { ($_[0] & S_IFMT()) == S_IFDIR()}
+sub S_ISCHR($)  { ($_[0] & S_IFMT()) == S_IFCHR()}
+sub S_ISBLK($)  { ($_[0] & S_IFMT()) == S_IFBLK()}
+sub S_ISREG($)  { ($_[0] & S_IFMT()) == S_IFREG()}
+sub S_ISFIFO($) { ($_[0] & S_IFMT()) == S_IFIFO()}
+sub S_ISLNK($)  { ($_[0] & S_IFMT()) == S_IFLNK()}
+sub S_ISSOCK($) { ($_[0] & S_IFMT()) == S_IFSOCK()}
+sub S_ISWHT($)  { ($_[0] & S_IFMT()) == S_IFWHT()}  # FreeBSD
+
+
 sub lchown($$@)
 {   my ($uid, $gid) = (shift, shift);
     my $successes = 0;
@@ -111,6 +111,12 @@ sub posix_glob($%)
     ($err, \@fns);
 }
 
+
+sub fnmatch($$;$)
+{   my ($pat, $name, $flags) = @_;
+    _fnmatch($pat, $name, $flags//0);
+}
+
 #---------
 
 sub _create_constant($)
