@@ -1,4 +1,3 @@
-
 /* __UL names are not defined to exist... and those names are
  * incompatible so we rename them. (kernel 2.6.37)
  */
@@ -10,3 +9,7 @@
 #ifndef UL_GETOPENMAX
 #define UL_GETOPENMAX __UL_GETOPENMAX
 #endif
+
+#ifdef __USE_FILE_OFFSET64
+#define HAS_RLIMIT_64
+#endif
